;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "vertico" "20260506.1941"
  "VERTical Interactive COmpletion."
  '((emacs  "29.1")
    (compat "31"))
  :url "https://github.com/minad/vertico"
  :commit "12799edfb6bf8de2b060d231dcefd9d9afb930b4"
  :revdesc "12799edfb6bf"
  :keywords '("convenience" "files" "matching" "completion")
  :authors '(("Daniel Mendler" . "mail@daniel-mendler.de"))
  :maintainers '(("Daniel Mendler" . "mail@daniel-mendler.de")))
